@@ -57,14 +57,13 @@ get_shape_id <- function(x, type = NULL, id = NULL, ph_label = NULL ){
 #' doc <- ph_remove(x = doc, type = "body", id = 1)
 #'
 #' print(doc, target = fileout )
-#' @importFrom xml2 xml_remove xml_find_all
 #' @family functions for placeholders manipulation
 #' @seealso \code{\link{ph_with}}
 ph_remove <- function( x, type = "body", id = 1, ph_label = NULL, id_chr = NULL ){
 
   slide <- x$slide$get_slide(x$cursor)
   office_id <- get_shape_id(x, type = type, id = id, ph_label = ph_label )
-  current_elt <- xml_find_first(slide$get(), sprintf("p:cSld/p:spTree/*[p:nvSpPr/p:cNvPr[@id='%s']]", office_id) )
+  current_elt <- xml_find_first(slide$get(), sprintf("p:cSld/p:spTree/*[*/p:cNvPr[@id='%s']]", office_id) )
 
   xml_remove(current_elt)
 
@@ -91,7 +90,6 @@ ph_remove <- function( x, type = "body", id = 1, ph_label = NULL, id_chr = NULL
 #' doc <- ph_slidelink(x = doc, ph_label = "Title 1", slide_index = 2)
 #'
 #' print(doc, target = fileout )
-#' @importFrom xml2 xml_remove xml_find_all
 #' @family functions for placeholders manipulation
 #' @seealso \code{\link{ph_with}}
 ph_slidelink <- function( x, type = "body", id = 1, id_chr = NULL, ph_label = NULL, slide_index){
@@ -132,7 +130,6 @@ ph_slidelink <- function( x, type = "body", id = 1, id_chr = NULL, ph_label = NU
 #'   href = "https://cran.r-project.org")
 #'
 #' print(doc, target = fileout )
-#' @importFrom xml2 xml_remove xml_find_all
 #' @family functions for placeholders manipulation
 #' @seealso \code{\link{ph_with}}
 ph_hyperlink <- function( x, type = "body", id = 1, id_chr = NULL, ph_label = NULL, href ){
@@ -174,12 +171,11 @@ ph_hyperlink <- function( x, type = "body", id = 1, id_chr = NULL, ph_label = NU
 #' fileout <- tempfile(fileext = ".pptx")
 #' my_pres <- read_pptx()
 #' my_pres <- add_slide(my_pres)
-#' my_pres <- ph_empty(my_pres,
+#' my_pres <- ph_with(my_pres, "",
 #'   location = ph_location_type(type = "body"))
 #'
 #' small_red <- fp_text(color = "red", font.size = 14)
 #'
-#' my_pres <- ph_add_par(my_pres, level = 3)
 #' my_pres <- ph_add_text(my_pres, str = "A small red text.",
 #'   style = small_red)
 #' my_pres <- ph_add_par(my_pres, level = 2)
@@ -194,15 +190,13 @@ ph_hyperlink <- function( x, type = "body", id = 1, id_chr = NULL, ph_label = NU
 #' doc <- add_slide(doc)
 #' doc <- ph_with(doc, "Un titre 2",
 #'   location = ph_location_type(type = "title"))
-#' doc <- ph_empty(doc,
+#' doc <- ph_with(doc, "",
 #'   location = ph_location(rotation = 90, bg = "red",
 #'       newlabel = "myph"))
-#' doc <- ph_add_par(doc, ph_label = "myph", level = 2)
-#' doc <- ph_add_text(doc, str = "Jump here to slide 2!",
+#' doc <- ph_add_text(doc, str = "dummy text",
 #'   ph_label = "myph")
 #'
 #' print(doc, target = fileout)
-#' @importFrom xml2 xml_child xml_children xml_add_child
 ph_add_text <- function( x, str, type = "body", id = 1, id_chr = NULL, ph_label = NULL,
                          style = fp_text(font.size = 0), pos = "after",
                          href = NULL, slide_index = NULL ){
@@ -220,13 +214,12 @@ ph_add_text <- function( x, str, type = "body", id = 1, id_chr = NULL, ph_label
   if( inherits(current_p, "xml_missing") )
     stop("Could not find any paragraph in the selected shape.")
 
-  r_shape_ <- sprintf(paste0( pml_with_ns("a:r"), "%s<a:t>%s</a:t></a:r>" ),
-                      format(style, type = "pml"),
-                      htmlEscape(str))
+  r_shape_ <- to_pml(ftext(text = str, prop = style), add_ns = TRUE)
 
-  if( pos == "after" )
-    where_ <- length(xml_children(current_p))
-  else where_ <- 0
+  if( pos == "after" ){
+    runset <- xml_find_all(slide$get(), sprintf("p:cSld/p:spTree/*[p:nvSpPr/p:cNvPr[@id='%s']]/a:p[last()]/a:r", office_id) )
+    where_ <- length(runset)
+  } else where_ <- 0
 
   new_node <- as_xml_document(r_shape_)
 
@@ -283,7 +276,6 @@ ph_add_text <- function( x, str, type = "body", id = 1, id_chr = NULL, ph_label
 #'               style = update(default_text, color = "blue"))
 #'
 #' print(doc, target = fileout)
-#' @importFrom xml2 xml_child xml_children xml_add_child
 ph_add_par <- function( x, type = "body", id = 1, id_chr = NULL, level = 1, ph_label = NULL ){
 
   slide <- x$slide$get_slide(x$cursor)
@@ -302,14 +294,15 @@ ph_add_par <- function( x, type = "body", id = 1, id_chr = NULL, level = 1, ph_l
     else
       p_shape <- "<a:p/>"
 
-    simple_shape <- paste0( pml_with_ns("p:txBody"), "<a:bodyPr/><a:lstStyle/>",
+    simple_shape <- paste0( "<p:txBody xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\">",
+                            "<a:bodyPr/><a:lstStyle/>",
                             p_shape, "</p:txBody>")
     xml_add_child(current_elt, as_xml_document(simple_shape) )
   } else {
     if( level > 1 ){
-      simple_shape <- sprintf(paste0( pml_with_ns("a:p"), "<a:pPr lvl=\"%.0f\"/></a:p>" ), level - 1)
+      simple_shape <- sprintf(paste0( ap_ns_yes, "<a:pPr lvl=\"%.0f\"/></a:p>" ), level - 1)
     } else
-      simple_shape <- paste0(pml_with_ns("a:p"), "</a:p>")
+      simple_shape <- paste0(ap_ns_yes, "</a:p>")
     xml_add_child(current_p, as_xml_document(simple_shape) )
   }
   x
@@ -341,11 +334,10 @@ ph_add_par <- function( x, type = "body", id = 1, id_chr = NULL, level = 1, ph_l
 #'
 #' doc <- read_pptx() %>%
 #'   add_slide(layout = "Title and Content", master = "Office Theme") %>%
-#'   ph_empty(location = ph_location(bg = "wheat", newlabel = "myph")) %>%
+#'   ph_with("", location = ph_location(bg = "wheat", newlabel = "myph")) %>%
 #'   ph_add_fpar(value = fpar_, ph_label = "myph", level = 2)
 #'
 #' print(doc, target = tempfile(fileext = ".pptx"))
-#' @importFrom xml2 xml_child xml_children xml_add_child
 #' @seealso \code{\link{fpar}}
 ph_add_fpar <- function( x, value, type = "body", id = 1, id_chr = NULL, ph_label = NULL,
                          level = 1, par_default = TRUE ){
@@ -360,12 +352,14 @@ ph_add_fpar <- function( x, value, type = "body", id = 1, id_chr = NULL, ph_labe
   current_elt <- xml_find_first(slide$get(), sprintf("p:cSld/p:spTree/*[p:nvSpPr/p:cNvPr[@id='%s']]", office_id) )
 
   current_p <- xml_child(current_elt, "/p:txBody")
-  newp_str <- format(value, type = "pml")
-  newp_str <- gsub("<a:p>", pml_with_ns("a:p"), newp_str )
-  node <- as_xml_document(newp_str)
+
+  node <- as_xml_document(to_pml(value, add_ns = TRUE))
+
   if( par_default ){
+    # add default pPr
     ppr <- xml_child(node, "/a:pPr")
-    empty_par <- as_xml_document(paste0(pml_with_ns("a:pPr"), "</a:pPr>"))
+    empty_par <- as_xml_document(paste0("<a:pPr xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\">",
+                                        "</a:pPr>"))
     xml_replace(ppr, empty_par )
   }
   ppr <- xml_child(node, "/a:pPr")
@@ -373,7 +367,8 @@ ph_add_fpar <- function( x, value, type = "body", id = 1, id_chr = NULL, ph_labe
     xml_attr(ppr, "lvl") <- sprintf("%.0f", level - 1)
   }
   if( inherits(current_p, "xml_missing") ){
-    simple_shape <- paste0( pml_with_ns("p:txBody"), "<a:bodyPr/><a:lstStyle/></p:txBody>")
+    simple_shape <- paste0( "<p:txBody xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" xmlns:p=\"http://schemas.openxmlformats.org/presentationml/2006/main\">",
+                            "<a:bodyPr/><a:lstStyle/></p:txBody>")
     newnode <- as_xml_document(simple_shape)
     xml_add_child(newnode, node)
     xml_add_child(current_elt, newnode )
